/*
* Fabric3
* Copyright (c) 2009-2011 Metaform Systems
*
* Fabric3 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version, with the
* following exception:
*
* Linking this software statically or dynamically with other
* modules is making a combined work based on this software.
* Thus, the terms and conditions of the GNU General Public
* License cover the whole combination.
*
* As a special exception, the copyright holders of this software
* give you permission to link this software with independent
* modules to produce an executable, regardless of the license
* terms of these independent modules, and to copy and distribute
* the resulting executable under terms of your choice, provided
* that you also meet, for each linked independent module, the
* terms and conditions of the license of that module. An
* independent module is a module which is not derived from or
* based on this software. If you modify this software, you may
* extend this exception to your version of the software, but
* you are not obligated to do so. If you do not wish to do so,
* delete this exception statement from your version.
*
* Fabric3 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty
* of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU General Public License for more details.
*
* You should have received a copy of the
* GNU General Public License along with Fabric3.
* If not, see <http://www.gnu.org/licenses/>.
*/
package org.fabric3.contribution.processor;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.osoa.sca.annotations.Destroy;
import org.osoa.sca.annotations.EagerInit;
import org.osoa.sca.annotations.Init;
import org.osoa.sca.annotations.Reference;

import org.fabric3.spi.contribution.Library;
import org.fabric3.spi.contribution.archive.ClasspathProcessor;
import org.fabric3.spi.contribution.archive.ClasspathProcessorRegistry;

/**
 * Creates the classpath for a a symbolic link contribution (*.contribution file). The contents of the file point to an exploded directory, which is
 * placed on the classpath.
 *
 * @version $Rev: 10392 $ $Date: 2011-05-30 13:55:50 +0000 (Mon, 30 May 2011) $
 */
@EagerInit
public class SymLinkClasspathProcessor implements ClasspathProcessor {

    private final ClasspathProcessorRegistry registry;

    public SymLinkClasspathProcessor(@Reference ClasspathProcessorRegistry registry) {
        this.registry = registry;
    }

    @Init
    public void init() {
        registry.register(this);
    }

    @Destroy
    public void destroy() {
        registry.unregister(this);
    }

    public boolean canProcess(URL url) {
        return url.toString().endsWith(".contribution");
    }

    public List<URL> process(URL url, List<Library> libraries) throws IOException {
        List<URL> classpath = new ArrayList<URL>();
        File root = deReferenceFile(url);
        classpath.add(root.toURI().toURL());
        File metaInfLib = new File(root, "META-INF" + File.separator + "lib");
        if (metaInfLib.exists()) {
            classpath.add(metaInfLib.toURI().toURL());
        }
        File webInfLib = new File(root, "WEB-INF" + File.separator + "lib");
        if (webInfLib.exists()) {
            classpath.add(webInfLib.toURI().toURL());
        }
        File webInfClasses = new File(root, "WEB-INF" + File.separator + "classes");
        if (webInfClasses.exists()) {
            classpath.add(webInfClasses.toURI().toURL());
        }
        return classpath;
    }

    private File deReferenceFile(URL url) throws IOException {
        InputStreamReader streamReader = new InputStreamReader(url.openStream());
        BufferedReader bufferedReader = new BufferedReader(streamReader);
        String line = bufferedReader.readLine().trim();
        return new File(line);
    }


}